summaryrefslogtreecommitdiff
path: root/sysdeps/x86_64/x32/dl-machine.h
diff options
context:
space:
mode:
authorSamuel Thibault <samuel.thibault@ens-lyon.org>2016-08-20 19:50:45 +0200
committerSamuel Thibault <samuel.thibault@ens-lyon.org>2016-08-20 19:50:45 +0200
commit4dd9e35bfd35d3138bc44169baba098005bad51e (patch)
treea4939c43a9c3fe00eb27f023e14acc5e1fe8808c /sysdeps/x86_64/x32/dl-machine.h
parentbd42a4599d1b6f77bcfe1e4f67b7cbd9e1cb2dfd (diff)
parentf76453c31593957fec1a99b986bfa5506618b79c (diff)
Merge commit 'refs/top-bases/t/bigmem' into t/bigmem
Diffstat (limited to 'sysdeps/x86_64/x32/dl-machine.h')
-rw-r--r--sysdeps/x86_64/x32/dl-machine.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sysdeps/x86_64/x32/dl-machine.h b/sysdeps/x86_64/x32/dl-machine.h
index 3ee41cf4a4..f5efaa5060 100644
--- a/sysdeps/x86_64/x32/dl-machine.h
+++ b/sysdeps/x86_64/x32/dl-machine.h
@@ -1,5 +1,5 @@
/* Machine-dependent ELF dynamic relocation inline functions. x32 version.
- Copyright (C) 2012-2014 Free Software Foundation, Inc.
+ Copyright (C) 2012-2015 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
@@ -62,7 +62,7 @@ _dl_start_user:\n\
movl %edx, %esi\n\
# Save %rsp value in %r13.\n\
movl %esp, %r13d\n\
# And align stack for the _dl_init_internal call.\n\
and $-16, %esp\n\
# _dl_loaded -> rdi\n\
movl _rtld_local(%rip), %edi\n\
@@ -73,7 +73,7 @@ _dl_start_user:\n\
# Clear %rbp to mark outermost frame obviously even for constructors.\n\
xorl %ebp, %ebp\n\
# Call the function to run the initializers.\n\
- call _dl_init_internal\n\
+ call _dl_init\n\
# Pass our finalizer function to the user in %rdx, as per ELF ABI.\n\
lea _dl_fini(%rip), %edx\n\
# And make sure %rsp points to argc stored on the stack.\n\
@@ -62,7 +62,7 @@ _dl_start_user:\n\
# Save %rsp value in %r13.\n\
movl %esp, %r13d\n\
- # And align stack for the _dl_init_internal call.\n\
+ # And align stack for the _dl_init call.\n\
and $-16, %esp\n\
# _dl_loaded -> rdi\n\